Secret

Struct Secret 

pub struct Secret { /* private fields */ }
Secret is somewhat like a Vec, but for sensitive data. It guarantees that its contents won’t be swapped out, and it also guarantees that the contents won’t be visible to any other process, or even the kernel.

NOTE: This requires a fairly recent kernel (5.14+), with CONFIG_SECRETMEM enabled. Currently there is no fallback implementation, so if requirements aren’t met, then constructing Secrets will simply return an error.

NOTE: Memory allocated this way does count towards RLIMIT_MEMLOCK. In modern kernels this defaults to 8 MiB, but it may perhaps need to be increased depending on how you’re using this.

Implementations

Source

impl Secret

pub fn new() -> Self

Create a new Secret buffer, initially with length zero. Before the buffer can be meaningfully used, resize will have to be called.

pub fn with_len(len: usize) -> Result<Self>

Create a new Secret buffer with the given initial length. The given initial length can be zero.

pub fn resize(&mut self, len: usize) -> Result<()>

Resize the buffer’s length in bytes. If the new length is smaller, the existing data is truncated. If the new length is larger, the new bytes will be zeros.

pub fn len(&self) -> usize

Return this buffer’s length in bytes.

pub unsafe fn slice_ptr(&self) -> *mut u8

Returns a pointer to this Secret’s underlying memory. The returned pointer is guaranteed to be suitable for constructing a slice, even if this Secret is empty. This pointer is guaranteed to be non-NULL.

pub unsafe fn as_slice(&self) -> &[u8]

Access the underlying secret data. This function is unsafe primarily because you’re touching secrets that shouldn’t be exposed, so be very careful what you do with the data!

pub unsafe fn as_mut_slice(&mut self) -> &mut [u8]

Mutably access the underlying secret data. This function is unsafe primarily because you’re touching secrets that shouldn’t be exposed, so be very careful what you do with the data!

pub fn try_clone(&self) -> Result<Self>

Try to copy this Secret’s contents into a new Secret.