IpNet

Struct IpNet 

pub struct IpNet { /* private fields */ }
An IpNet represents an IP network. Networks are typically identified in CIDR notation, like (for example) “192.0.0.0/24”.

Implementations

Source

impl IpNet

pub fn get_ip(&self) -> IpAddr

Return the network IP. This address will have been normalized, such that any non-masked bits will have been turned off during construction.

pub fn get_mask(&self) -> &[u8]

Return the network mask, as a byte slice. This slice will always be 16 bytes long, even if this is an IPv4 network.

pub fn apply_mask(&self, ip: IpAddr, invert: bool, set: bool) -> IpAddr

Apply this network’s mask to the given IP address, returning the modified copy.

The “default” behavior is when invert=false and set=false. In this case, any bits which are “0” in the mask are turned off in the given IP address’ bytes.

If invert=true, then each bit in the mask is flipped before it is applied - in other words, we apply the inverse mask.

If set=true, then we switch from bitwise AND to bitwise OR, meaning instead of the behavior described above, any bits which are “1” in the mask are turned on in the IP address, and other bits are left unchanged.

pub fn get_one_bits(&self) -> usize

Returns the number of “1” bits in this network’s mask. Although the mask is always 16 bytes long, for IPv4 networks only the last 4 bytes of the mask are considered.

pub fn is_canonical(&self) -> bool

Returns whether or not this network’s mask is “canonical” - i.e., if all of its mask’s “1” bits are contiguous (no “0” bits in-between them).

pub fn netmask(&self) -> IpAddr

Return the netmask IP address for this network.

pub fn broadcast(&self) -> IpAddr

Return the broadcast IP address for this network.

pub fn contains(&self, ip: IpAddr, strict: bool) -> bool

Return whether or not the given IP address is contained within this network. If strict=true, then the “network address” and “broadcast address” are both not considered to be “within” this network (this is useful if you want to check if the given IP address is actually usable for a host on the network).

pub fn increment_in(&self, ip: IpAddr, strict: bool) -> Option<IpAddr>

Increment the given IP address as if with increment_ip(), but returning None if the resulting IP address does not lie within this network. The “strict” parameter behaves as IpNet::contains() describes.

pub fn first(&self) -> Option<IpAddr>

Return the first IP address which falls within this network.

For networks with no distinct network address (/32 for IPv4 and /128 for IPv6, which contain only a single host; and /31 for IPv4 and /127 for IPv6, where per RFC 3021 / RFC 6164 both addresses are usable), self.ip is returned. Otherwise the network address is skipped and self.ip + 1 is returned.

pub fn last(&self) -> IpAddr

Return the last non-broadcast IP address which falls within this network.